#
# spec file for package flare
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flare
Version:        1.14
Release:        1.8
Summary:        Free Libre Action Roleplaying Engine
License:        (CC-BY-SA-3.0 OR CC-BY-SA-4.0) AND GPL-3.0-or-later
Group:          Amusements/Games/RPG
URL:            https://flarerpg.org
Source0:        https://github.com/flareteam/flare-game/releases/download/v%{version}/%{name}-engine-v%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  vim
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
Requires:       %{name}-game = %{version}
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun):hicolor-icon-theme
Requires(postun):update-desktop-files
Recommends:     python
Provides:       %{name}-engine = %{version}

%description
Flare (Free Libre Action Roleplaying Engine) is a game engine built
to handle a very specific kind of game: single-player 2D action RPGs.
Flare is not a reimplementation of an existing game or engine. It is a
tribute to and exploration of the action RPG genre.

The usecase of this project is to build several real games and
reuse code. The first game, in progress, is a fantasy dungeon crawl.

Flare uses .ini-style config files for most of the
game data to modify game contents. The game code is C++.

%prep
%setup -q -n %{name}-engine-v%{version}
# W: desktopfile-without-binary flare.desktop /usr/bin/flare
sed -i 's/@FLARE_EXECUTABLE_PATH@/%{name}/g' distribution/flare.desktop.in

%build
%cmake \
    -DBINDIR="bin" \
    -DDATADIR="share/flare" \
    -DCMAKE_BUILD_TYPE="Release" \
    -DCMAKE_INSTALL_PREFIX="%{_prefix}"
%cmake_build

%install
%cmake_install
%fdupes -s %{buildroot}/%{_prefix}

%files
%license COPYING
%doc README* RELEASE_NOTES.txt
%{_bindir}/%{name}
%{_mandir}/man*/%{name}.*
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%changelog
* Thu Dec 29 2022 Dirk Müller <dmueller@suse.com>
- update to v1.14:
  Engine features
  * Added 'loot.requires_status' and 'status_loot' properties to loot table
    definitions.
  * Support '/' as shorthand for 'exec' in the dev console. A space is not
    required after the slash.
  * Added 'spawn_level' property to map enemies. This follows the same
    syntax as the Power property of the same name.
  * Add XP scaling tables for scaling enemy reward XP based on enemy level.
  * Replace 'immunity' effects with percentage-based resistances.
  * Added 'mouse_move_deadzone' property to engine/misc.txt to help
    alleviate erratic mouse-move behavior when the cursor is near the
    player.
  * Alternative tab UI for when tabs exceed the available space.
  * Added keybind for cycling equipment sets in reverse.
  * Refactored stats and stat bonuses to use floats for fractional values.
  * Support fractional values in the following:
  * Added 'resource_round_method' property to engine/combat.txt.
  * Support arbitrary "MP-like" resources:
  * Configuration file: engine/resource_stats.txt
  * Added 'requires_resource_stat' and 'resource_steal' properties to
    Powers.
  * Added 'requires_resource_stat_state' and
    'requires_resource_stat_state_mode' properties to Powers.
  * Added 'enabled' property to MenuStatBar definitions.
  Engine fixes
  * Fixed set item tooltips showing incorrect number of equipped items if a
    set item was on an inactive loadout.
  * Fixed dev console commands not working if they were preceded by
    whitespace.
  * Fixed spawning entities not counting towards summoned entity count.
  * Fix broken gamepad navigation after closing Powers menu while on a non-
    default tab.
  * Removed hard-coded minimum values for HP/MP steal and damage return.
  * Fixed "activate" message incorrectly showing in MenuPowers tooltips.
  * Fix some cases where 'min' damage/absorb could be greater than the
    cooresponding 'max' value.
  * Fixed text input issues with deleting text on Android.
  Game updates
  * Fireball and Ice Bolt scrolls now give the player a 10 second period in
    which their basic attacks (Swing, Shoot, Channel) are replaced with the
    scroll power.
  * Fixed the naming of scroll damage as it appears in power description
    tooltips.
  * Lowered Lezaith's slow resistance to 50%%, down from 100%%
  * Lowered Lezaith's stun resistance to 90%%, down from 100%%
  * Translation updates
* Sat May  7 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.13.04
  * Added 'bar_gfx' property to menus/enemy.txt for setting the "fill" image
  * Fix crash when trying to read a non-existent file with INCLUDE
  * Fix passive powers not being correctly re-applied after death
  * Improve performance of WidgetListBox by caching all items
    instead of just the visible ones
* Sat Feb  5 2022 Carsten Ziepke <kieltux@gmail.com>
- Version update to 1.13
  Engine features
  * Added additional requirement properties (requires_status,
    requires_item, etc) to enemy and NPC map objects. The properties
    now match what is available for map events.
  * When ‘mouse aim’ is disabled, the Shift key can now be used with
    the direction keys to change the player’s orientation without
    moving.
  * Added optional ‘fog-of-war’ feature
  * Added support for multiple sets/loadouts of equipped items
  * Added random_status attribute to Events for setting/unsetting a
    random status from a list.
  * Reworked gamepad handling using the SDL_GameController API.
  * Several new key bindings, many of which will benefit gamepad
    users.
  * Added an “action picker” for interacting with items/powers when
    using a gamepad or a touchscreen.
  * Added misc.selection_rect_corner_size to
    engine/widget_settings.txt. This allows for a nicer “targeting
    reticle” appearance when selecting widgets without a mouse.
  * Added ‘background’ property for all menus. Menus will fall back to
    the existing hard-coded filenames if this property is omitted.
  * Added ‘close’, ‘label_title’, and ‘action_list’ properties to
    MenuConfirm configuration.
  * Added ‘render_layers’ section to StatBlock definitions. It has the
    same syntax and functionality as engine/hero_layers.txt, so that
    file is now considered deprecated.
  * Added ‘animation_slots’ section to StatBlock definitions. This
    allows for multiple animation layers on non-player entities that
    don’t have an inventory like the player.
  * Added a ‘direction’ property to map NPCs, indentical to the
    property of the same name for map enemies.
  * Added ‘vendor_ratio_buy’, ‘vendor_ratio_sell’, and
  ‘vendor_ratio_sell_old’ properties to engine/loot.txt. These
  deprecate ‘vendor_ratio’ and ‘vendor_ratio_buyback’.
  * Added ‘vendor_ratio_buy’, ‘vendor_ratio_sell’, and
    ‘vendor_ratio_sell_old’ properties to NPCs. These can be used to
    override the global settings in engine/loot.txt.
  * Added ‘tooltip_visible_max’ to engine/tootlips.txt to control the
    maximum number of visible floating tooltips.
  Engine fixes
  * Fix enemies not being able to target NPC followers
  * Fix loot and sound effects being cleared in StatBlock files with
    multiple sections
  * Fix potential crash when removing summons that would be
    out-of-bounds on the next map.
  * Fix bug where a damage type with no name could be removed if
    another damage type was defined after it.
  * Don’t show hidden stats under ‘Related Stats’ section of tooltips
    of Character menu.
  * Fix bug where negative regen wouldn’t work if the resource was
    100%% full.
  * Fix bug where negative regen would overflow after reaching zero.
  * Fix bug that caused built-in effect types to be ignored by Power
    post_effect.
  * Fix disappearing sprites due to render priority overflow.
  * Fading of corpses is now correctly disabled when corpse_timeout=0
    is used in engine/misc.txt.
  * Fix cast animation not playing when using an inventory item that
    is not instant.
  * Fixed a bug on Android where loading the default settings would
    exit fullscreen mode.
  * Fixed crash in NPC dialog when using gamepad.
  * Fixed several small bugs with navigating UI elements with a
    gamepad.
  * Fixed incorrect handling of gamepad stick/trigger deadzone.
  * Fixed fullscreen setting being turned off when loading
    configuration defaults on Android.
  * Fixed input hint for item tooltips when using a touchscreen.
  * Improved file access handling on Android versions 10 and up. This
    fixes the infinite cutscene loop when starting a new game.
  * Fixed memory leak when loading NPCs.
  * Entity animations will now fall back to the ‘die’ animation when
  ‘critdie’ isn’t defined.
  * Improved text rendering by blending text with a copy of itself.
  * Fix infinite loop that could occur when setting unlocked powers.
  * Elemental resistances can now be used with ‘stat’,
  ‘stat_per_level’, and ‘stat_per_primary’ in StatBlock definitions.
- Run spec-cleaner
* Sun Sep  5 2021 saku nix <ssakuragi2@hotmail.com>
- Version update to 1.12
  Engine features
  * NPC interactions are now canceled when the player is attacked.
    ‘combat_aborts_npc_interact’ has been added to engine/misc.txt to control
    this setting.
  * Added ‘bar_fill_offset’ and ‘bar_fill_size’ to MenuStatBar and MenuEnemy
    properties.
  * Added support for fading out combat text. See the ‘fade_duration’ property
    in engine/combat.txt.
  * Added ‘save_oncutscene’ property to engine/misc.txt. Saving before a cutscene
    was previously controlled with ‘save_onload’, which caused issues with
    cutscenes when set to false.
  * Added ‘save_anywhere’ property to engine/misc.txt. This allows for saving
    via the pause menu. (m7600)
  * Added display of enemies, allies, NPCs, and intermap teleport events to the
    minimap.
  * Added support for defining the colors of tiles and entities on the minimap.
  * Added ‘show_on_minimap’ event component. Currently, this only applies to
    intermap teleport events.
  * Added ‘show_on_minimap’ property to NPCs.
  * Properties that take an alignment can now be aligned to the menu frame.
  * Support multiple images in animation definitions. (bloodhero)
  * Expanded slot widget configuration in engine/widget_settings.txt. Quantity
    text color can be changed, as well as label settings for displaying hotkeys.
  * Re-implemented displaying hotkeys on action bar slots.
  * Support for ‘item:quantity’ syntax for Event properties: ‘requires_item’,
    ‘requires_not_item’, ‘remove_item’, and ‘reward_item’.
  * Added ‘show_randomize’ property to new game menu configuration.
  * Added ‘disable_equip_slots’ property for passive powers.
  * ‘Block’ powers can now use post_power to trigger a power when taking damage.
  * Power descriptions are now displayed in action bar tooltips. This can be
    controlled with the ‘tooltip_length’ property in menus/actionbar.txt.
  * A dialog box is now displayed instead of a log message when the player dies,
    giving the options to exit or respawn (if applicable).
  * Added movement input type dialog box. It is displayed for new players to
    easily select between keyboard, mouse, and joystick movement.
  * Added ‘–safe-video’ command line option. For troubleshooting purposes, this
    feature is displayed as an option when starting after a potential crash.
  * The ‘categories’ property has been extended to the player character. The
    Power property ‘target_categories’ can now be used for the player as a result.
  * The ability to stash quest items can now be controlled with the ‘no_stash’ property.
  * Added a button for opening the pause/configuration menu as part of the minimap.
  * Added ‘script’ property to items. This removes the need to create a power in
    order to execute a script via activating an item.
  * Player ‘melee_range’ is now configurable in engine/stats.txt.
  * Added comparison tooltips for items. These can be disabled in the Interface
    settings. (r-a-cristian-93, Justin Jacobs)
  * Added ‘parallax_layers’ property to Events. This functions exactly like the
    Map property of the same name.
  * Added ‘visible’, ‘visible_check_locked’, and ‘visible_check_status’ to powers
    and upgrades in power trees.
  * Added ‘requires_status’ and ‘requires_not_status’ to powers and upgrades in
    power trees. ‘visible_requires_status’ and ‘visible_requires_not_status’
    have been marked as deprecated.
  * Added ‘on_interact’ as a possible value for Event types. Essentially the
    same as ‘on_trigger’, except the event can ONLY be activated through the hotspot.
  * Support an arbitrary number of Stash tabs. Each tab has a display name and
    an ‘is_private’ flag.
  * Added ‘save_onstash’ property to engine/misc.txt, so it is now possible to
    disable the automatic save when modifying stash contents.
  * The player’s last used Stash tab is now remembered across sessions.
  * Added the ability for NPCs to join the player’s party. (Igor Paliychuk)
  * Added support for the ‘delay’ property used by Events contained in script files.
  * Added ‘Frame Limit’ option to Video settings.
  * Added ‘Maximum Render Size’ option to Video settings.
  * Improved visual indication of which item set bonuses are active.
  * Support enabling touch screen controls on non-Android systems.
  * Added ‘Touch Gamepad Scale’ option to Input settings.
  * Support fullscreen mode in the Emscripten port.
  * Added scrollbar.bg_color to engine/widget_settings.txt.
  * Updates to package_osx.sh, including usage of Homebrew for dependencies (ludoza)
  Engine fixes
  * Fix memory leak of tab control in stash menu (MiroslavR)
  * Fixed stat bars not having any fill when the value they were representing was
    non-zero. Now they will always show at least 1 pixel of the bar’s fill graphics.
  * Fixed a bug where the game window could be resized below the minimum size after
    exiting fullscreen mode.
  * Removed the default resolution scaling when virtual_heights is undefined.
  * Improved performance when checking map event hotspots.
  * Fix Windows-style paths with backslashes not working on non-Windows systems.
  * Prevent allies counting as attack targets when using mouse movement.
  * Fix needing to press the ‘Cancel’ key twice to exit the vendor menu.
  * Fix unintended key presses being registered when quitting the game via an OS
    keyboard shortcut.
  * Fix divide-by-zero crash when using the dev HUD with a game that uses
    orthogonal rendering.
  * Fixed a memory leak in Loot copy constructor.
  * Fixed ‘resist_percent’ property of engine/combat.txt not working when targets
    had 100%% resistance.
  * Support attack_speed effects with a magnitude less than 100%%.
  * Fixed bug where dead entities could steal HP/MP.
  * Fix broken parsing of engine/default_keybindings.txt.
  * Fix Effect animations not being synced properly in some cases.
  * Removed hard-coded restrictions on using items from the inventory. Now any
    item that has a power and is not equipment can be used.
  * Fix crash when fonts are missing. The engine will try to fall back to the next
    available font for the current language.
  * Background color when using sdl_hardware renderer no longer fills entire
    window, instead only filling the drawing surface as it should.
  * Fix crash when loading a cutscene from a book event.
  * Fix infinite transformation loop when dying in a transformed state that was
    activated by a passive power.
  * Fix bug where the player wasn’t returned to their normal state after dying
    in a transformed state.
  * Prevent combat text from overlapping.
  * Improved performance when handling many status effects.
  * Improved performance when an entity is repeatedly unable to find a path to
    thier target.
  * Fix bug where killing an enemy with return damage would not set defeat status
    or reward XP/loot.
  * Fix check of item requirements when a power requires an item but doesn’t
    consume it.
  * Fix ‘respec’ events to no longer remove item-based powers from the action bar.
  * Fix log message when gaining more than one level at once.
  * Fixed excessive memory usage when using Items, ItemSets, and Powers with high-value IDs.
  * Fix bug where power upgrades that didn’t require power points would not
    automatically upgrade if other requirements were met.
  * Fix infinite loop bug when a power’s list of upgrades contains the base power ID.
  * Fix infinite loop bug when locking power upgrades.
  * The executable directory is now used when trying to find PATH_DATA on Linux. (r-a-cristian-93)
  * Fix ‘corpse_timeout’ in engine/misc.txt being parsed incorrectly (r-a-cristian-93)
  * Reworked camera speed curve to prevent graphical “wiggle” during slow movement.
  * Fix missing effect description text in power tooltips when using built-in types.
  * Fix static events not executing on the same frame as on_load events.
  * Fix parsing bug in power trees that would save base power properties to an upgrade power.
  * Fix on_load events with requires_class not working in maps/spawn.txt
  * Fix timing of Effects so that the first “tick” happens immediately.
  * Fix “Press button to use” prompt no showing up for some items.
  * Fix loud loot drop sound effect when there are a large number of drops at once.
  * Fix incorrect HP/MP regen for high regen values and high frame limits.
  * Fix camera, parallax layer, and cutscene speeds when using alternative frame limits.
  * Fix not restoring fullscreen option when pressing Cancel or Defaults in config menu.
  * Smoother scrolling in WidgetScrollBox.
  * Fix click-and-drag behavior on WidgetTabControl, WidgetSlider, and WidgetScrollBar.
  * Fix dialog topics being auto-selected when they shouldn’t for non-vendor NPCs.
* Sun Jul 28 2019 Max Mitschke <maxmitschke@fastmail.com>
- Version update to 1.11
  Engine Features
  * Players now have their own private stash in addition to the
    shared stash.
  * Expanded the 'no_stash' Item variable to account for having
    multiple stashes.
  Engine Fixes
  * Fix bug where items could be dragged from the vendor window and
    dropped in the opposite vendor tab.
  * Fix bug that caused item max_quantity to be reset when attempting
    to append an item definition.
  * Fix bug where Powers with 'replace_by_effect' would still use
    properties from the parent power, such as animation state.
- Removed post/postun macros since they are no longer needed with
  Leap 42.3 going end-of-life.
* Sat May 18 2019 Max Mitschke <maxmitschke@fastmail.com>
- Version update to 1.10
  Engine Features
  * The configuration menu has been redesigned and is now used as the pause menu.
  * The interface features from version 1.09 have been reverted due to being
    accessible from the pause menu.
  * Added an Interface option to disable showing hidden entity markers.
  * Support floating point values for loot drop chance values.
  * Add ‘hide_timeout’ option to stat bar configuration to support auto-hiding.
  * Added an Interface option to disable stat bar auto-hiding globally.
  * Add ‘no_stash’ property to item definitions to prevent items from being
    placed in the stash.
  * Add low HP notification system. (Leszek Cimała)
  * Add ability to change the minimap zoom level by clicking on the minimap.
  Engine Fixes
  * Fixed event activation being tied to distance to the camera position. It is
    now correctly tied to distance from the player.
  * Mouse movement and mouse aim now calculate direction relative to the player
    instead of relative to the screen.
  * Fixed enemy AI so that enemies can now enter combat if a hero ally is in
    their proximity.
  * Fix –data-path command line flag on Windows.
  * Fixed dialog not being available if it lacked a topic.
  * Fixed loot drop rate bonus having no effect when loot drop chance was too
    low.
  * Fix bug where the wrong requirements were checked for passive powers that
    had been granted bonus points.
  * Items that can’t be stashed are now dropped on the ground upon opening the
    stash.
  * Prevent re-binding the primary Main1 binding, which could break many
    interactions.
  * Removed the ability to re-bind the Ctrl, Shift, Alt, and Delete keys, since
    they correspond to specific keyboard keys.
  * Fix crash when trying to load a mod that contained
    ‘engine/default_keybindings.txt’.
  * Display XP stat bar value as relative to current level instead of total XP.
  * Fix key bindings not working when switched to a non-US keyboard layout.
  * Fix segfault when NPC filename is invalid.
  * Fix inventory tooltips covering books when using no mouse.
  * Fix navigation of dialog menu when using no mouse.
  * Fix upgrading powers when using no mouse.
  * When using the sdl_hardware renderer on Windows, OpenGL will now be used
    instead of Direct3D. This fixes the loss of some textures when resizing
    the window.
  * Fixed the “level up” string to represent the ability to allocate multiple
    stat points. Also note if Power points can be allocated.
  * Refactored ‘requires_hpmp_state’ for Powers to check against both stats at
    once. See the attribute reference for syntax changes.
  * Greatly improved performance of loot tooltips.
  * Fix bug where high item find chance prevented the player from finding
    currency.
* Mon Dec 17 2018 maxmitschke@fastmail.com
- Version update to 1.09.01
  * Fixed assertion/crash when engaging in dialog.
  * Updated Ukranian translations
- Version update to 1.09
  * Add ‘save_pos_onexit’ to engine/misc.txt for saving the
    player’s current position upon exiting.
  * Add ‘toggle_fps’ to the developer console commands.
  * Add a video setting to disable parallax layers.
  * Add ability to use icons in books.
  * Add item property ‘book_is_readable’ to control displaying
    ‘read’ vs ‘use’ in item tooltips.
  * Add renderer support for batching calls to local pixel drawing.
    This speeds up the pre-render of the minimap.
  * Add support for shadows on book text via ‘text_shadow’.
  * Add tooltips to language list to show language codes.
  * Added ‘colorblind_highlight_offset’ and listbox ‘text_margin’
    to engine/widget_settings.txt.
  * Added a 2x zoom mode for the mini-map.
  * Added a compass to the minimap.
  * Added Catalan translations
  * Added support for dialog responses. For any line of dialog, a
    list of response topics can be given.
  * Closing a book with the ‘Cancel’ key no longer closes all
    other menus.
  * Dialog options are no longer shown in a separate menu, but are
    instead part of the main dialog window.
  * Fix book open sound effect not being played in all cases.
  * Fix buttons and checkboxes not handling clicks while the
    “Accept” key is pressed.
  * Fix handling of disabled widgets when using keyboard navigation.
  * Fix incorrect descriptions of controls on mobile devices.
  * Fix potential memory leak when redefining images in books.
  * Fixed a bug where looped map sounds wouldn’t play if the player
    entered the map with a sound volume of 0, but later raised
    the volume.
  * Fixed shrinking tab widgets when widow was resized.
  * Loot tooltips can now be hidden when entities are near pieces of
    loot. The setting “hide_radius” has been added to engine/loot.txt
    to control this.
  * Make strings related to elements more translator-friendly.
  * Missing items now maintain their stack quantity when moved around.
  * Moved several interface options to the actionbar. Loot tooltips,
    combat text, statbar labels, and mini-map mode can be adjusted.
  * Moved the interface option for automatically equipping items to
    the Inventory menu.
  * New mouse movement options to swap the movement button and/or
    restrict the movement button to be movement-only.
  * Overhead markers are now displayed for entities that are
    obscured by tall tiles.
  * Redesigned mouse movement with better handling of non-melee attacks.
  * Remove broken ‘font_fallback’ from engine/font_settings.txt.
  * Updated translations for German, Scottish Gaelic,
    Brazilian Portueguese, Ukranian, Vietnamese
  * Using consumables from the Inventory menu will now subtract from
    the stack that was clicked on.
  * Widgets that use custom images can now fall back to the
    default image if the custom image is missing
    (instead of exiting in failure).
- Updated location of flare-engine data directory to follow
  packaging standards
- Added more CMake build params to to have install process
  follow packaging standards
* Tue Oct 23 2018 maxmitschke@fastmail.com
- Version update to 1.08
  * Updated translations for German, French, Scottish Gaelic and
    Italian
  * Bugfixes
* Sun Jun 17 2018 maxmitschke@fastmail.com
- Version update to 1.06
* Wed Mar 14 2018 jengelh@inai.de
- Trim bias and filler wording from description.
* Wed Mar 14 2018 tchvatal@suse.com
- Version update to 1.0 release:
  * No real upstream changelog but first non-alpha release supporting
    big campaign mode.
- Remove unused condition for license
- Cleanup a bit
* Mon Jun 27 2016 dap.darkness@gmail.com
- Prevented openSUSE 13.1' error (invalid-license CC-BY-SA-4.0).
* Sun May 29 2016 dap.darkness@gmail.com
- Version bump to 0.20:
  * no upstream changelog.
- Tarball & spec for data subpackage.
- License, *Requires, %%description were fixed up.
- RelWithDebInfo build type to provide debuginfo.
- Verbose make.
- Valid %%post(un).
* Thu Nov 20 2014 tchvatal@suse.com
- Version bump to 0.19:
  * Lots of various improvements. See ChangeLog
- Remove _service and use rather tarball next to pkg with possiblity to
  local service run of download_files
- Use cmake macro and overall cleanup of .spec
* Sat Apr  6 2013 dap.darkness@gmail.com
- 0.18 release
  * 10 Equipment Slots, up from 4 (and easily configurable)
  * Starting "Class" choice (beginner's power/item kit)
  * Environmental/Ambient Sounds on maps
  * Much improved handling of Animations, Effects, and Sounds
  * New Powers: Stealth, Traps, Thrown Weapons
  * New Item Bonuses: XP gain, Gold Find, Item Find, and more
  * Improved support for various input devices
- Service source_validator was enabled.
- Spec header was fixed up according to distro policy.
- Sources were moved from GitHub to SourceForge.
- Spec was fixed up via `spec-cleaner`.
- Requires hicolor-icon-theme not to pack unnecessary dirs.
- Python became recommended, not required.
- xgettext.py & readme.txt might be executable.
* Tue Oct  2 2012 dap.darkness@gmail.com
- 0.17.1 release
  * Instant-sell items now go to the vendor Buyback tab
  * Disable New/Load buttons if there is no story mod loaded
  * Prevent crash when binding higher number mouse buttons
  * Prevent crash when loading a map with missing layers
  * Add helpful tooltips when play buttons are disabled
  * Removed -flto compiler flag from default build script
* Sun Sep 30 2012 dap.darkness@gmail.com
- 0.17 release
  * All menus now easy to mod/reskin
  * New Powers tree with traditional tabs and spendable points
  * Shared Stash! Collect epics, hoard resist gear, or buff your new characters
  * Warp Zone - fast-travel map to get around the alpha demo campaign
- Clean section was removed.
- Url was updated.
* Sun Jul  8 2012 dap.darkness@gmail.com
- 0.16 release
  * Improved enemy pathfinding, including flying creatures
  * Summon or transform into enemies!
  * Config menu including keybindings, mods, and more
  * Orthogonal map support
* Thu May 31 2012 dap.darkness@gmail.com
- git
  * Configuration menu was implemented
- Build improvements
  * Cmake build type became "RelWithDebInfo"
  * Cmake verbose makefile became "True"
  * Binary path fixing patch was replaced by cmake option.
  * Rpm optimisation flags were enabled.
* Sun Dec 25 2011 dap.darkness@gmail.com
- 0.15.1 release
  * Fixes a couple issues (build flags, random enemy groups)
* Fri Dec 23 2011 dap.darkness@gmail.com
- 0.15 release
  * Now using TTF for fonts
  * All game data can be overwritten/added via mods
  * Translation support for the core engine and mods
  * New Grassland tileset
  * New questing areas: Frontier and Living Bones
  * Redesigned creatures are tougher and more varied
